/** Copyright (C) Joonas Pihlajamaa 2012. 
 * Licenced under GNU GPL, see Licence.txt for details
 * Analyze some things in the captured signal. */

 #include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <conio.h>

#include "ps2000.h"

#define CAPTURE_LENGTH (1000*1000)

short * streaming_buffer;
long streaming_ptr;

void  __stdcall ps2000FastStreamingReady(short **overviewBuffers, 
		short overflow, unsigned long triggeredAt, short triggered, 
		short auto_stop, unsigned long nValues) {
	long i;
	short * channel_A = overviewBuffers[0];
	
	for(i=0; i<nValues && streaming_ptr < CAPTURE_LENGTH; i++)
		streaming_buffer[streaming_ptr++] = channel_A[i];
}

int main(int argc, char *argv[]) {
	short handle;
	int i, capture_interval;
	int count[65536];
	
	capture_interval = 500;
	
	handle = ps2000_open_unit();
	
	ps2000_set_channel(handle, PS2000_CHANNEL_A, TRUE, 1, PS2000_5V);
	ps2000_set_channel(handle, PS2000_CHANNEL_B, FALSE, 1, PS2000_5V);
	
	// No trigger
	ps2000_set_trigger(handle, PS2000_NONE, 0, PS2000_RISING, 0, 0);
	
	streaming_buffer = (short *)malloc(sizeof(short) * CAPTURE_LENGTH);
	streaming_ptr = 0;
	
	// Collect a maximum of 100 000 samples, no auto-stop, no aggregation (1 samples aggregated), 50 k overview buffer
	if(capture_interval < 1000)
		ps2000_run_streaming_ns(handle, capture_interval, PS2000_NS, 1000000, 0, 1, 500000);
	else
		ps2000_run_streaming_ns(handle, capture_interval/1000, PS2000_US, 1000000, 0, 1, 500000);
	
	while(!_kbhit() && streaming_ptr < CAPTURE_LENGTH) {
		ps2000_get_streaming_last_values(handle, ps2000FastStreamingReady);
		//printf("%ld\n", streaming_ptr);
		Sleep (0);
	}
	
	ps2000_stop(handle);

	ps2000_close_unit(handle);
	
	for(i=0; i<65536; i++)
		count[i] = 0;
		
	for(i=0; i<CAPTURE_LENGTH; i++) {
		count[streaming_buffer[i] + 32768]++;
	}
	
	float sum = 0.0;
	for(i=0; i<65536; i++) {
		sum += (float)count[i];
		if(count[i])
			printf("%5d x %d (%f %.1f %%)\n", i-32768, count[i], sum, 100 * sum / (float)CAPTURE_LENGTH);
	}
		
	return 0;
}
